# Audit Plan: ADR-0.22.0-task-level-governance

## Scope
- ADR: `docs/design/adr/pre-release/ADR-0.22.0-task-level-governance/ADR-0.22.0-task-level-governance.md`
- Generated: 2026-03-28

## Verification Commands
- `uv run gz test`
- `uv run gz lint`
- `uv run gz typecheck`
- `uv run mkdocs build --strict`

## Proof Output
- Directory: `docs/design/adr/pre-release/ADR-0.22.0-task-level-governance/audit/proofs`
